==> fireflutter-0.3.14.tar.gz: lib/src/widget/comment/comment_list_view.dart <==
import 'dart:developer';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_ui_firestore/firebase_ui_firestore.dart';
import 'package:fireflutter/fireflutter.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class CommentListView extends StatefulWidget {
  const CommentListView({
    super.key,
    this.itemBuilder,
    this.blockedBuilder,
    this.emptyBuilder,
    this.pageSize = 10,
    this.scrollController,
    this.primary,
    this.physics,
    this.shrinkWrap = false,
    this.padding,
    this.dragStartBehavior = DragStartBehavior.start,
    this.keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual,
    this.clipBehavior = Clip.hardEdge,
    required this.post,
    this.commentTileRunSpacing = 8,
    this.commentTilePadding,
    this.commentTileTopSpacing = 8,
  });

  final int pageSize;
  final Widget Function(BuildContext context, Comment comment)? itemBuilder;
  final Widget Function(BuildContext context, Comment comment)? blockedBuilder;
  final Widget Function(BuildContext context)? emptyBuilder;
  final ScrollController? scrollController;
  final bool? primary;
  final ScrollPhysics? physics;
  final bool shrinkWrap;
  final EdgeInsetsGeometry? padding;

  final DragStartBehavior dragStartBehavior;
  final ScrollViewKeyboardDismissBehavior keyboardDismissBehavior;
  final Clip clipBehavior;
  final double commentTileRunSpacing;
  final EdgeInsetsGeometry? commentTilePadding;
  final double commentTileTopSpacing;
  final Post post;

  @override
  State<CommentListView> createState() => CommentListViewState();
}

class CommentListViewState extends State<CommentListView> {
  @override
  Widget build(BuildContext context) {
    return FirestoreListView(
      query: commentCol.where("postId", isEqualTo: widget.post.id).orderBy("sort"),
      itemBuilder: (context, QueryDocumentSnapshot snapshot) {
        final comment = Comment.fromDocumentSnapshot(snapshot);
        if (my?.hasBlocked(comment.uid) ?? false) {
          if (widget.blockedBuilder != null) {
            return widget.blockedBuilder!(context, comment);
          }
          // TODO ongoing review - comment list
          if (widget.itemBuilder != null) {
            return widget.itemBuilder!(context, comment);
          }
          return CommentOneLineListTile(
            runSpacing: widget.commentTileRunSpacing,
            padding: widget.commentTilePadding,
            post: widget.post,
            comment: comment,
          );
        }
        if (widget.itemBuilder != null) {
          return widget.itemBuilder!(context, comment);
        }
        return CommentOneLineListTile(
          runSpacing: widget.commentTileRunSpacing,
          padding: widget.commentTilePadding,
          post: widget.post,
          comment: comment,
        );
      },
      emptyBuilder: (context) {
        if (widget.emptyBuilder != null) {
          return widget.emptyBuilder!(context);
        }
        return Column(
          children: [
            Center(child: Text(tr.noComment)),
            const SizedBox(height: 60),
          ],
        );
      },
      errorBuilder: (context, error, stackTrace) {
        log(error.toString(), stackTrace: stackTrace);
        return Center(child: Text('Error loading posts $error'));
      },
      pageSize: widget.pageSize,
      controller: widget.scrollController,
      primary: widget.primary,
      physics: widget.physics,
      shrinkWrap: widget.shrinkWrap,
      padding: widget.padding,
      dragStartBehavior: widget.dragStartBehavior,
      keyboardDismissBehavior: widget.keyboardDismissBehavior,
      clipBehavior: widget.clipBehavior,
    );
  }
}

==> fireflutter-0.3.15.tar.gz: lib/src/widget/comment/comment_list_view.dart <==
import 'dart:developer';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_ui_firestore/firebase_ui_firestore.dart';
import 'package:fireflutter/fireflutter.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class CommentListView extends StatefulWidget {
  const CommentListView({
    super.key,
    this.itemBuilder,
    this.blockedBuilder,
    this.emptyBuilder,
    this.pageSize = 10,
    this.scrollController,
    this.primary,
    this.physics,
    this.shrinkWrap = false,
    this.padding,
    this.dragStartBehavior = DragStartBehavior.start,
    this.keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual,
    this.clipBehavior = Clip.hardEdge,
    required this.post,
    this.commentTileRunSpacing = 8,
    this.commentTilePadding,
    this.commentTileTopSpacing = 8,
  });

  final int pageSize;
  final Widget Function(BuildContext context, Comment comment)? itemBuilder;
  final Widget Function(BuildContext context, Comment comment)? blockedBuilder;
  final Widget Function(BuildContext context)? emptyBuilder;
  final ScrollController? scrollController;
  final bool? primary;
  final ScrollPhysics? physics;
  final bool shrinkWrap;
  final EdgeInsetsGeometry? padding;

  final DragStartBehavior dragStartBehavior;
  final ScrollViewKeyboardDismissBehavior keyboardDismissBehavior;
  final Clip clipBehavior;
  final double commentTileRunSpacing;
  final EdgeInsetsGeometry? commentTilePadding;
  final double commentTileTopSpacing;
  final Post post;

  @override
  State<CommentListView> createState() => CommentListViewState();
}

class CommentListViewState extends State<CommentListView> {
  @override
  Widget build(BuildContext context) {
    return FirestoreListView(
      query:
          commentCol.where("postId", isEqualTo: widget.post.id).orderBy("sort"),
      itemBuilder: (context, QueryDocumentSnapshot snapshot) {
        final comment = Comment.fromDocumentSnapshot(snapshot);
        if (my?.hasBlocked(comment.uid) ?? false) {
          if (widget.blockedBuilder != null) {
            return widget.blockedBuilder!(context, comment);
          }
          if (widget.itemBuilder != null) {
            return widget.itemBuilder!(context, comment);
          }
          return CommentOneLineListTile(
            runSpacing: widget.commentTileRunSpacing,
            padding: widget.commentTilePadding,
            post: widget.post,
            comment: comment,
          );
        }
        if (widget.itemBuilder != null) {
          return widget.itemBuilder!(context, comment);
        }
        return CommentOneLineListTile(
          runSpacing: widget.commentTileRunSpacing,
          padding: widget.commentTilePadding,
          post: widget.post,
          comment: comment,
        );
      },
      emptyBuilder: (context) {
        if (widget.emptyBuilder != null) {
          return widget.emptyBuilder!(context);
        }
        return Column(
          children: [
            Center(child: Text(tr.noComment)),
            const SizedBox(height: 60),
          ],
        );
      },
      errorBuilder: (context, error, stackTrace) {
        log(error.toString(), stackTrace: stackTrace);
        return Center(child: Text('Error loading posts $error'));
      },
      pageSize: widget.pageSize,
      controller: widget.scrollController,
      primary: widget.primary,
      physics: widget.physics,
      shrinkWrap: widget.shrinkWrap,
      padding: widget.padding,
      dragStartBehavior: widget.dragStartBehavior,
      keyboardDismissBehavior: widget.keyboardDismissBehavior,
      clipBehavior: widget.clipBehavior,
    );
  }
}
